direction_deg

Function direction_deg 

pub fn direction_deg(heading_deg: f64, wind_angle_deg: f64) -> f64
The compass direction the wind blows from, given the vessel’s heading and a wind angle off the bow.

For a vessel heading 350° with the wind 30° off the bow to starboard:

N heading: 350° wind angle off bow: +30° wind direction: 020°